==> aria2-1.16.0.tar.bz2: aria2-1.16.0/src/UTMetadataRequestFactory.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2009 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_UT_METADATA_REQUEST_FACTORY_H
#define D_UT_METADATA_REQUEST_FACTORY_H

#include "common.h"

#include <vector>

#include "SharedHandle.h"
#include "Command.h"

namespace aria2 {

class PieceStorage;
class DownloadContext;
class Peer;
class BtMessageDispatcher;
class BtMessageFactory;
class UTMetadataRequestTracker;
class BtMessage;

class UTMetadataRequestFactory {
private:
  SharedHandle<DownloadContext> dctx_;

  SharedHandle<Peer> peer_;

  BtMessageDispatcher* dispatcher_;

  BtMessageFactory* messageFactory_;

  UTMetadataRequestTracker* tracker_;
  cuid_t cuid_;
public:
  UTMetadataRequestFactory();

  // Creates at most num of ut_metadata request message and appends
  // them to msgs. pieceStorage is used to identify missing piece.
  void create(std::vector<SharedHandle<BtMessage> >& msgs, size_t num,
              const SharedHandle<PieceStorage>& pieceStorage);

  void setDownloadContext(const SharedHandle<DownloadContext>& dctx)
  {
    dctx_ = dctx;
  }

  void setBtMessageDispatcher(BtMessageDispatcher* disp)
  {
    dispatcher_ = disp;
  }

  void setBtMessageFactory(BtMessageFactory* factory)
  {
    messageFactory_ = factory;
  }

  void setPeer(const SharedHandle<Peer>& peer)
  {
    peer_ = peer;
  }

  void setUTMetadataRequestTracker(UTMetadataRequestTracker* tracker)
  {
    tracker_ = tracker;
  }

  void setCuid(cuid_t cuid)
  {
    cuid_ = cuid;
  }
};

} // namespace aria2

#endif // D_UT_METADATA_REQUEST_FACTORY_H

==> aria2_1.18.1.orig.tar.bz2: aria2-1.18.1/src/UTMetadataRequestFactory.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2009 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_UT_METADATA_REQUEST_FACTORY_H
#define D_UT_METADATA_REQUEST_FACTORY_H

#include "common.h"

#include <vector>
#include <memory>

#include "Command.h"

namespace aria2 {

class PieceStorage;
class DownloadContext;
class Peer;
class BtMessageDispatcher;
class BtMessageFactory;
class UTMetadataRequestTracker;
class BtMessage;

class UTMetadataRequestFactory {
private:
  DownloadContext* dctx_;

  std::shared_ptr<Peer> peer_;

  BtMessageDispatcher* dispatcher_;

  BtMessageFactory* messageFactory_;

  UTMetadataRequestTracker* tracker_;
  cuid_t cuid_;
public:
  UTMetadataRequestFactory();

  // Creates and returns at most num of ut_metadata request
  // message. pieceStorage is used to identify missing piece.
  std::vector<std::unique_ptr<BtMessage>> create
  (size_t num, PieceStorage* pieceStorage);

  void setDownloadContext(DownloadContext* dctx)
  {
    dctx_ = dctx;
  }

  void setBtMessageDispatcher(BtMessageDispatcher* disp)
  {
    dispatcher_ = disp;
  }

  void setBtMessageFactory(BtMessageFactory* factory)
  {
    messageFactory_ = factory;
  }

  void setPeer(const std::shared_ptr<Peer>& peer)
  {
    peer_ = peer;
  }

  void setUTMetadataRequestTracker(UTMetadataRequestTracker* tracker)
  {
    tracker_ = tracker;
  }

  void setCuid(cuid_t cuid)
  {
    cuid_ = cuid;
  }
};

} // namespace aria2

#endif // D_UT_METADATA_REQUEST_FACTORY_H
